#[non_exhaustive]pub struct CompilationUnitCairoPluginMetadata {
pub package: PackageId,
pub component_dependency_id: Option<CompilationUnitComponentId>,
pub prebuilt_allowed: Option<bool>,
pub extra: HashMap<String, Value>,
}Expand description
Information about compiler plugin to load into the Cairo compiler as part of a compilation unit.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.package: PackageIdPackage ID.
component_dependency_id: Option<CompilationUnitComponentId>An id which uniquely identifies the plugin in scope of the compilation unit amongst other plugins and CU components. It is used to identify the plugin as a possible dependency of a CU component.
prebuilt_allowed: Option<bool>Whether Scarb will attempt to load prebuilt binaries associated with this plugin.
extra: HashMap<String, Value>Additional data not captured by deserializer.