#[non_exhaustive]pub struct CompilationUnitComponentDependencyMetadata {
pub id: CompilationUnitComponentId,
pub extra: HashMap<String, Value>,
}Expand description
Information about dependency of a component of a compilation unit.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: CompilationUnitComponentIdAn id of a component from the same compilation unit that this dependency refers to. It represents either a library or a plugin. It is guaranteed to be unique in the scope of the compilation unit.
extra: HashMap<String, Value>Additional data not captured by deserializer.