pub struct SourceId {
pub repr: String,
}Expand description
An “opaque” identifier for a source.
It is possible to inspect the repr field if the need arises,
but its precise format is an implementation detail and is subject to change.
Fields
repr: StringThe underlying string representation of the ID.